#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import sys
import traceback

import certifi
import urllib3
from colorama import init
from termcolor import colored

# WORKAROUND below in case certificate is not install on workstation
# urllib3.disable_warnings()

# use Colorama to make Termcolor work on Windows too
init()

http = urllib3.PoolManager(
    cert_reqs="CERT_REQUIRED",
    ca_certs=certifi.where(),
)


# USAGE : python -m get_jira.test.check_certificates

print(colored("TEST: https://google.com", "yellow"))

try:

    r = http.request("GET", "https://google.com")
    print(r.status)

except urllib3.exceptions.SSLError as e:
    print(e)
    #    sys.stderr.write("Failed to check certificate.  Message: \"%s\".\n" % (e.text));
    sys.exit(2)
except Exception as e:  # noqa: ignore=E722
    traceback.print_exc()
    print(
        colored(
            "Oops!  HTTPS is failing. Switch to manual... {}".format(
                http,
            ),
            "red",
        ),
    )
    sys.exit(2)

print(colored("TEST: https://expired.badssl.com", "yellow"))

try:

    r = http.request("GET", "https://expired.badssl.com")
    print(r.status)
    # http = urllib3.PoolManager(
    #    cert_file='/etc/ssl/certs/UK1VSWCERT01-CA-5.crt',
    #    cert_reqs='CERT_REQUIRED',
    #    ca_certs='/etc/ssl/certs/ca-certificates.crt')
    sys.exit(2)

except urllib3.exceptions.MaxRetryError as e:
    #    traceback.print_exc()
    print(
        colored(
            "OK!  HTTPS is failing. As expected... {}".format(
                e,
            ),
            "green",
        ),
    )
except urllib3.exceptions.SSLError as e:
    print(e)
except Exception as e:  # noqa: ignore=E722
    traceback.print_exc()
    print(
        colored(
            "Oops!  HTTPS is failing. Switch to manual... {}".format(
                http,
            ),
            "red",
        ),
    )

print(colored("TEST: http://fr1cslfrbm0060.misys.global.ad/", "yellow"))

# http = urllib3.PoolManager(
#    cert_file='/etc/ssl/certs/UK1VSWCERT01-CA-5.crt',
#    cert_reqs='CERT_REQUIRED',
#    ca_certs='/etc/ssl/certs/ca-certificates.crt')

try:

    r = http.request("GET", "http://fr1cslfrbm0060.misys.global.ad/")
    print(r.status)

    # sys.exit(2)

except urllib3.exceptions.MaxRetryError as e:
    #    traceback.print_exc()
    print(
        colored(
            "OK!  HTTPS is failing. As expected... {}".format(
                e,
            ),
            "green",
        ),
    )
except urllib3.exceptions.SSLError as e:
    print(e)
except Exception as e:  # noqa: ignore=E722
    traceback.print_exc()
    print(
        colored(
            "Oops!  HTTPS is failing. Switch to manual... {}".format(
                http,
            ),
            "red",
        ),
    )

print(colored("TEST: https://almtools.misys.global.ad/jira", "yellow"))

try:

    r = http.request("GET", "https://almtools.misys.global.ad/jira")
    print(r.status)

    sys.exit(2)

except urllib3.exceptions.MaxRetryError as e:
    #    traceback.print_exc()
    print(
        colored(
            "OK!  HTTPS is failing. As expected... {}".format(
                e,
            ),
            "green",
        ),
    )
except urllib3.exceptions.SSLError as e:
    print(e)
except Exception as e:  # noqa: ignore=E722
    traceback.print_exc()
    print(
        colored(
            "Oops!  HTTPS is failing. Switch to manual... {}".format(
                http,
            ),
            "red",
        ),
    )



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
    This module allow to customize git hooks.
"""
# import hooks.get_jira  # noqa: F401
import uuid

from hooks._version import get_versions
# from . import _version

name = 'hooks'

signing_uuid = uuid.UUID('dd34b62f-9ed5-597e-85a2-c15d48ed6832')
__version__ = get_versions()['version']
del get_versions

# __version__ = 'v1.0.2'
# __version__ = _version.get_versions()['version']

__all__ = ('__version__', 'signing_uuid')



# -*- coding: utf-8 -*-
import os
import sys
import unittest

# import get_jira.get_auth as script1  # The code to test

# sys.path.append("../hooks")
sys.path.append("./hooks")

# import get_jira.get_jira as script2 # The code to test

# python -m get_jira.get_jira feature/BMT-13403 -v
# python -m get_jira.get_auth -u aandrieu -p XXXX -v
# ./get_msg.py '../.git/COMMIT_EDITMSG'


class TestMyPackage(unittest.TestCase):
    def setUp(self):
        self.local_test_dir = os.path.dirname(os.path.realpath(__file__))

    def test_always_passes(self):
        self.assertTrue


if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
# This file helps to compute a version number in source trees obtained from
# git-archive tarball (such as those provided by githubs download-from-tag
# feature). Distribution tarballs (built by setup.py sdist) and build
# directories (produced by setup.py build) will contain a much shorter file
# that just contains the computed version number.
# This file is released into the public domain. Generated by
# versioneer-0.21 (https://github.com/python-versioneer/python-versioneer)
"""Git implementation of _version.py."""
import errno
import os
import re
import subprocess
import sys
from typing import Callable
from typing import Dict


def get_keywords():
    """Get the keywords needed to look up the version information."""
    # these strings will be replaced by git during git-archive.
    # setup.py/versioneer.py will grep for the variable names, so they must
    # each be defined on a line of their own. _version.py will just call
    # get_keywords().
    git_refnames = '$Format:%d$'
    git_full = '$Format:%H$'
    git_date = '$Format:%ci$'
    keywords = {'refnames': git_refnames, 'full': git_full, 'date': git_date}
    return keywords


class VersioneerConfig:
    """Container for Versioneer configuration parameters."""


def get_config():
    """Create, populate and return the VersioneerConfig() object."""
    # these strings are filled in when 'setup.py versioneer' creates
    # _version.py
    cfg = VersioneerConfig()
    cfg.VCS = 'git'
    cfg.style = 'pep440'
    cfg.tag_prefix = 'v'
    cfg.parentdir_prefix = 'nabla-hooks-'
    cfg.versionfile_source = 'hooks/_version.py'
    cfg.verbose = False
    return cfg


class NotThisMethod(Exception):
    """Exception raised if a method is not valid for the current scenario."""


LONG_VERSION_PY: Dict[str, str] = {}
HANDLERS: Dict[str, Dict[str, Callable]] = {}


def register_vcs_handler(vcs, method):  # decorator
    """Create decorator to mark a method as the handler of a VCS."""
    def decorate(f):
        """Store f in HANDLERS[vcs][method]."""
        if vcs not in HANDLERS:
            HANDLERS[vcs] = {}
        HANDLERS[vcs][method] = f
        return f
    return decorate


def run_command(
    commands, args, cwd=None, verbose=False, hide_stderr=False,
    env=None,
):
    """Call the given command(s)."""
    assert isinstance(commands, list)  # nosec - ✅ skip B101 : Use of assert detected
    process = None
    for command in commands:
        try:
            dispcmd = str([command] + args)
            # remember shell=False, so use git.cmd on windows, not just git
            process = subprocess.Popen(
                [command] + args, cwd=cwd, env=env,
                stdout=subprocess.PIPE,
                stderr=(
                    subprocess.PIPE if hide_stderr
                    else None
                ),
            )
            break
        except OSError:
            e = sys.exc_info()[1]
            if e.errno == errno.ENOENT:
                continue
            if verbose:
                print('unable to run %s' % dispcmd)
                print(e)
            return None, None
    else:
        if verbose:
            print('unable to find command, tried {}'.format(commands))
        return None, None
    stdout = process.communicate()[0].strip().decode()
    if process.returncode != 0:
        if verbose:
            print('unable to run %s (error)' % dispcmd)
            print('stdout was %s' % stdout)
        return None, process.returncode
    return stdout, process.returncode


def versions_from_parentdir(parentdir_prefix, root, verbose):
    """Try to determine the version from the parent directory name.

    Source tarballs conventionally unpack into a directory that includes both
    the project name and a version string. We will also support searching up
    two directory levels for an appropriately named parent directory
    """
    rootdirs = []

    for _ in range(3):
        dirname = os.path.basename(root)
        if dirname.startswith(parentdir_prefix):
            return {
                'version': dirname[len(parentdir_prefix):],
                'full-revisionid': None,
                'dirty': False, 'error': None, 'date': None,
            }
        rootdirs.append(root)
        root = os.path.dirname(root)  # up a level

    if verbose:
        print(
            'Tried directories %s but none started with prefix %s' %
            (str(rootdirs), parentdir_prefix),
        )
    raise NotThisMethod("rootdir doesn't start with parentdir_prefix")


@register_vcs_handler('git', 'get_keywords')
def git_get_keywords(versionfile_abs):
    """Extract version information from the given file."""
    # the code embedded in _version.py can just fetch the value of these
    # keywords. When used from setup.py, we don't want to import _version.py,
    # so we do it with a regexp instead. This function is not used from
    # _version.py.
    keywords = {}
    try:
        with open(versionfile_abs, 'r') as fobj:
            for line in fobj:
                if line.strip().startswith('git_refnames ='):
                    mo = re.search(r'=\s*"(.*)"', line)
                    if mo:
                        keywords['refnames'] = mo.group(1)
                if line.strip().startswith('git_full ='):
                    mo = re.search(r'=\s*"(.*)"', line)
                    if mo:
                        keywords['full'] = mo.group(1)
                if line.strip().startswith('git_date ='):
                    mo = re.search(r'=\s*"(.*)"', line)
                    if mo:
                        keywords['date'] = mo.group(1)
    except OSError:
        pass
    return keywords


@register_vcs_handler('git', 'keywords')
def git_versions_from_keywords(keywords, tag_prefix, verbose):
    """Get version information from git keywords."""
    if 'refnames' not in keywords:
        raise NotThisMethod('Short version file found')
    date = keywords.get('date')
    if date is not None:
        # Use only the last line.  Previous lines may contain GPG signature
        # information.
        date = date.splitlines()[-1]

        # git-2.2.0 added "%cI", which expands to an ISO-8601 -compliant
        # datestamp. However we prefer "%ci" (which expands to an "ISO-8601
        # -like" string, which we must then edit to make compliant), because
        # it's been around since git-1.5.3, and it's too difficult to
        # discover which version we're using, or to work around using an
        # older one.
        date = date.strip().replace(' ', 'T', 1).replace(' ', '', 1)
    refnames = keywords['refnames'].strip()
    if refnames.startswith('$Format'):
        if verbose:
            print('keywords are unexpanded, not using')
        raise NotThisMethod('unexpanded keywords, not a git-archive tarball')
    refs = {r.strip() for r in refnames.strip('()').split(',')}
    # starting in git-1.8.3, tags are listed as "tag: foo-1.0" instead of
    # just "foo-1.0". If we see a "tag: " prefix, prefer those.
    TAG = 'tag: '
    tags = {r[len(TAG):] for r in refs if r.startswith(TAG)}
    if not tags:
        # Either we're using git < 1.8.3, or there really are no tags. We use
        # a heuristic: assume all version tags have a digit. The old git %d
        # expansion behaves like git log --decorate=short and strips out the
        # refs/heads/ and refs/tags/ prefixes that would let us distinguish
        # between branches and tags. By ignoring refnames without digits, we
        # filter out many common branch names like "release" and
        # "stabilization", as well as "HEAD" and "master".
        tags = {r for r in refs if re.search(r'\d', r)}
        if verbose:
            print("discarding '%s', no digits" % ','.join(refs - tags))
    if verbose:
        print('likely tags: %s' % ','.join(sorted(tags)))
    for ref in sorted(tags):
        # sorting will prefer e.g. "2.0" over "2.0rc1"
        if ref.startswith(tag_prefix):
            r = ref[len(tag_prefix):]
            # Filter out refs that exactly match prefix or that don't start
            # with a number once the prefix is stripped (mostly a concern
            # when prefix is '')
            if not re.match(r'\d', r):
                continue
            if verbose:
                print('picking %s' % r)
            return {
                'version': r,
                'full-revisionid': keywords['full'].strip(),
                'dirty': False, 'error': None,
                'date': date,
            }
    # no suitable tags, so version is "0+unknown", but full hex is still there
    if verbose:
        print('no suitable tags, using unknown + full revision id')
    return {
        'version': '0+unknown',
        'full-revisionid': keywords['full'].strip(),
        'dirty': False, 'error': 'no suitable tags', 'date': None,
    }


@register_vcs_handler('git', 'pieces_from_vcs')
def git_pieces_from_vcs(tag_prefix, root, verbose, runner=run_command):
    """Get version from 'git describe' in the root of the source tree.

    This only gets called if the git-archive 'subst' keywords were *not*
    expanded, and _version.py hasn't already been rewritten with a short
    version string, meaning we're inside a checked out source tree.
    """
    GITS = ['git']
    TAG_PREFIX_REGEX = '*'
    if sys.platform == 'win32':
        GITS = ['git.cmd', 'git.exe']
        TAG_PREFIX_REGEX = r'\*'

    _, rc = runner(
        GITS, ['rev-parse', '--git-dir'], cwd=root,
        hide_stderr=True,
    )
    if rc != 0:
        if verbose:
            print('Directory %s not under git control' % root)
        raise NotThisMethod("'git rev-parse --git-dir' returned error")

    # if there is a tag matching tag_prefix, this yields TAG-NUM-gHEX[-dirty]
    # if there isn't one, this yields HEX[-dirty] (no NUM)
    describe_out, rc = runner(
        GITS, [
            'describe', '--tags', '--dirty',
            '--always', '--long',
            '--match',
            '{}{}'.format(tag_prefix, TAG_PREFIX_REGEX),
        ],
        cwd=root,
    )
    # --long was added in git-1.5.5
    if describe_out is None:
        raise NotThisMethod("'git describe' failed")
    describe_out = describe_out.strip()
    full_out, rc = runner(GITS, ['rev-parse', 'HEAD'], cwd=root)
    if full_out is None:
        raise NotThisMethod("'git rev-parse' failed")
    full_out = full_out.strip()

    pieces = {}
    pieces['long'] = full_out
    pieces['short'] = full_out[:7]  # maybe improved later
    pieces['error'] = None

    branch_name, rc = runner(
        GITS, ['rev-parse', '--abbrev-ref', 'HEAD'],
        cwd=root,
    )
    # --abbrev-ref was added in git-1.6.3
    if rc != 0 or branch_name is None:
        raise NotThisMethod("'git rev-parse --abbrev-ref' returned error")
    branch_name = branch_name.strip()

    if branch_name == 'HEAD':
        # If we aren't exactly on a branch, pick a branch which represents
        # the current commit. If all else fails, we are on a branchless
        # commit.
        branches, rc = runner(GITS, ['branch', '--contains'], cwd=root)
        # --contains was added in git-1.5.4
        if rc != 0 or branches is None:
            raise NotThisMethod("'git branch --contains' returned error")
        branches = branches.split('\n')

        # Remove the first line if we're running detached
        if '(' in branches[0]:
            branches.pop(0)

        # Strip off the leading "* " from the list of branches.
        branches = [branch[2:] for branch in branches]
        if 'master' in branches:
            branch_name = 'master'
        elif not branches:
            branch_name = None
        else:
            # Pick the first branch that is returned. Good or bad.
            branch_name = branches[0]

    pieces['branch'] = branch_name

    # parse describe_out. It will be like TAG-NUM-gHEX[-dirty] or HEX[-dirty]
    # TAG might have hyphens.
    git_describe = describe_out

    # look for -dirty suffix
    dirty = git_describe.endswith('-dirty')
    pieces['dirty'] = dirty
    if dirty:
        git_describe = git_describe[:git_describe.rindex('-dirty')]

    # now we have TAG-NUM-gHEX or HEX

    if '-' in git_describe:
        # TAG-NUM-gHEX
        mo = re.search(r'^(.+)-(\d+)-g([0-9a-f]+)$', git_describe)
        if not mo:
            # unparsable. Maybe git-describe is misbehaving?
            pieces['error'] = (
                "unable to parse git-describe output: '%s'"
                % describe_out
            )
            return pieces

        # tag
        full_tag = mo.group(1)
        if not full_tag.startswith(tag_prefix):
            if verbose:
                fmt = "tag '%s' doesn't start with prefix '%s'"
                print(fmt % (full_tag, tag_prefix))
            pieces['error'] = (
                "tag '%s' doesn't start with prefix '%s'"
                % (full_tag, tag_prefix)
            )
            return pieces
        pieces['closest-tag'] = full_tag[len(tag_prefix):]

        # distance: number of commits since tag
        pieces['distance'] = int(mo.group(2))

        # commit: short hex revision ID
        pieces['short'] = mo.group(3)

    else:
        # HEX: no tags
        pieces['closest-tag'] = None
        count_out, rc = runner(GITS, ['rev-list', 'HEAD', '--count'], cwd=root)
        pieces['distance'] = int(count_out)  # total number of commits

    # commit date: see ISO-8601 comment in git_versions_from_keywords()
    date = runner(GITS, ['show', '-s', '--format=%ci', 'HEAD'], cwd=root)[0].strip()
    # Use only the last line.  Previous lines may contain GPG signature
    # information.
    date = date.splitlines()[-1]
    pieces['date'] = date.strip().replace(' ', 'T', 1).replace(' ', '', 1)

    return pieces


def plus_or_dot(pieces):
    """Return a + if we don't already have one, else return a ."""
    if '+' in pieces.get('closest-tag', ''):
        return '.'
    return '+'


def render_pep440(pieces):
    """Build up version string, with post-release "local version identifier".

    Our goal: TAG[+DISTANCE.gHEX[.dirty]] . Note that if you
    get a tagged build and then dirty it, you'll get TAG+0.gHEX.dirty

    Exceptions:
    1: no tags. git_describe was just HEX. 0+untagged.DISTANCE.gHEX[.dirty]
    """
    if pieces['closest-tag']:
        rendered = pieces['closest-tag']
        if pieces['distance'] or pieces['dirty']:
            rendered += plus_or_dot(pieces)
            rendered += '%d.g%s' % (pieces['distance'], pieces['short'])
            if pieces['dirty']:
                rendered += '.dirty'
    else:
        # exception #1
        rendered = '0+untagged.%d.g%s' % (
            pieces['distance'],
            pieces['short'],
        )
        if pieces['dirty']:
            rendered += '.dirty'
    return rendered


def render_pep440_branch(pieces):
    """TAG[[.dev0]+DISTANCE.gHEX[.dirty]] .

    The ".dev0" means not master branch. Note that .dev0 sorts backwards
    (a feature branch will appear "older" than the master branch).

    Exceptions:
    1: no tags. 0[.dev0]+untagged.DISTANCE.gHEX[.dirty]
    """
    if pieces['closest-tag']:
        rendered = pieces['closest-tag']
        if pieces['distance'] or pieces['dirty']:
            if pieces['branch'] != 'master':
                rendered += '.dev0'
            rendered += plus_or_dot(pieces)
            rendered += '%d.g%s' % (pieces['distance'], pieces['short'])
            if pieces['dirty']:
                rendered += '.dirty'
    else:
        # exception #1
        rendered = '0'
        if pieces['branch'] != 'master':
            rendered += '.dev0'
        rendered += '+untagged.%d.g%s' % (
            pieces['distance'],
            pieces['short'],
        )
        if pieces['dirty']:
            rendered += '.dirty'
    return rendered


def pep440_split_post(ver):
    """Split pep440 version string at the post-release segment.

    Returns the release segments before the post-release and the
    post-release version number (or -1 if no post-release segment is present).
    """
    vc = str.split(ver, '.post')
    return vc[0], int(vc[1] or 0) if len(vc) == 2 else None


def render_pep440_pre(pieces):
    """TAG[.postN.devDISTANCE] -- No -dirty.

    Exceptions:
    1: no tags. 0.post0.devDISTANCE
    """
    if pieces['closest-tag']:
        if pieces['distance']:
            # update the post release segment
            tag_version, post_version = pep440_split_post(pieces['closest-tag'])
            rendered = tag_version
            if post_version is not None:
                rendered += '.post%d.dev%d' % (post_version + 1, pieces['distance'])
            else:
                rendered += '.post0.dev%d' % (pieces['distance'])
        else:
            # no commits, use the tag as the version
            rendered = pieces['closest-tag']
    else:
        # exception #1
        rendered = '0.post0.dev%d' % pieces['distance']
    return rendered


def render_pep440_post(pieces):
    """TAG[.postDISTANCE[.dev0]+gHEX] .

    The ".dev0" means dirty. Note that .dev0 sorts backwards
    (a dirty tree will appear "older" than the corresponding clean one),
    but you shouldn't be releasing software with -dirty anyways.

    Exceptions:
    1: no tags. 0.postDISTANCE[.dev0]
    """
    if pieces['closest-tag']:
        rendered = pieces['closest-tag']
        if pieces['distance'] or pieces['dirty']:
            rendered += '.post%d' % pieces['distance']
            if pieces['dirty']:
                rendered += '.dev0'
            rendered += plus_or_dot(pieces)
            rendered += 'g%s' % pieces['short']
    else:
        # exception #1
        rendered = '0.post%d' % pieces['distance']
        if pieces['dirty']:
            rendered += '.dev0'
        rendered += '+g%s' % pieces['short']
    return rendered


def render_pep440_post_branch(pieces):
    """TAG[.postDISTANCE[.dev0]+gHEX[.dirty]] .

    The ".dev0" means not master branch.

    Exceptions:
    1: no tags. 0.postDISTANCE[.dev0]+gHEX[.dirty]
    """
    if pieces['closest-tag']:
        rendered = pieces['closest-tag']
        if pieces['distance'] or pieces['dirty']:
            rendered += '.post%d' % pieces['distance']
            if pieces['branch'] != 'master':
                rendered += '.dev0'
            rendered += plus_or_dot(pieces)
            rendered += 'g%s' % pieces['short']
            if pieces['dirty']:
                rendered += '.dirty'
    else:
        # exception #1
        rendered = '0.post%d' % pieces['distance']
        if pieces['branch'] != 'master':
            rendered += '.dev0'
        rendered += '+g%s' % pieces['short']
        if pieces['dirty']:
            rendered += '.dirty'
    return rendered


def render_pep440_old(pieces):
    """TAG[.postDISTANCE[.dev0]] .

    The ".dev0" means dirty.

    Exceptions:
    1: no tags. 0.postDISTANCE[.dev0]
    """
    if pieces['closest-tag']:
        rendered = pieces['closest-tag']
        if pieces['distance'] or pieces['dirty']:
            rendered += '.post%d' % pieces['distance']
            if pieces['dirty']:
                rendered += '.dev0'
    else:
        # exception #1
        rendered = '0.post%d' % pieces['distance']
        if pieces['dirty']:
            rendered += '.dev0'
    return rendered


def render_git_describe(pieces):
    """TAG[-DISTANCE-gHEX][-dirty].

    Like 'git describe --tags --dirty --always'.

    Exceptions:
    1: no tags. HEX[-dirty]  (note: no 'g' prefix)
    """
    if pieces['closest-tag']:
        rendered = pieces['closest-tag']
        if pieces['distance']:
            rendered += '-%d-g%s' % (pieces['distance'], pieces['short'])
    else:
        # exception #1
        rendered = pieces['short']
    if pieces['dirty']:
        rendered += '-dirty'
    return rendered


def render_git_describe_long(pieces):
    """TAG-DISTANCE-gHEX[-dirty].

    Like 'git describe --tags --dirty --always -long'.
    The distance/hash is unconditional.

    Exceptions:
    1: no tags. HEX[-dirty]  (note: no 'g' prefix)
    """
    if pieces['closest-tag']:
        rendered = pieces['closest-tag']
        rendered += '-%d-g%s' % (pieces['distance'], pieces['short'])
    else:
        # exception #1
        rendered = pieces['short']
    if pieces['dirty']:
        rendered += '-dirty'
    return rendered


def render(pieces, style):
    """Render the given version pieces into the requested style."""
    if pieces['error']:
        return {
            'version': 'unknown',
            'full-revisionid': pieces.get('long'),
            'dirty': None,
            'error': pieces['error'],
            'date': None,
        }

    if not style or style == 'default':
        style = 'pep440'  # the default

    if style == 'pep440':
        rendered = render_pep440(pieces)
    elif style == 'pep440-branch':
        rendered = render_pep440_branch(pieces)
    elif style == 'pep440-pre':
        rendered = render_pep440_pre(pieces)
    elif style == 'pep440-post':
        rendered = render_pep440_post(pieces)
    elif style == 'pep440-post-branch':
        rendered = render_pep440_post_branch(pieces)
    elif style == 'pep440-old':
        rendered = render_pep440_old(pieces)
    elif style == 'git-describe':
        rendered = render_git_describe(pieces)
    elif style == 'git-describe-long':
        rendered = render_git_describe_long(pieces)
    else:
        raise ValueError("unknown style '%s'" % style)

    return {
        'version': rendered, 'full-revisionid': pieces['long'],
        'dirty': pieces['dirty'], 'error': None,
        'date': pieces.get('date'),
    }


def get_versions():
    """Get version information or return default if unable to do so."""
    # I am in _version.py, which lives at ROOT/VERSIONFILE_SOURCE. If we have
    # __file__, we can work backwards from there to the root. Some
    # py2exe/bbfreeze/non-CPython implementations don't do __file__, in which
    # case we can only use expanded keywords.

    cfg = get_config()
    verbose = cfg.verbose

    try:
        return git_versions_from_keywords(
            get_keywords(), cfg.tag_prefix,
            verbose,
        )
    except NotThisMethod:
        pass

    try:
        root = os.path.realpath(__file__)
        # versionfile_source is the relative path from the top of the source
        # tree (where the .git directory might live) to this file. Invert
        # this to find the root from __file__.
        for _ in cfg.versionfile_source.split('/'):
            root = os.path.dirname(root)
    except NameError:
        return {
            'version': '0+unknown', 'full-revisionid': None,
            'dirty': None,
            'error': 'unable to find root of source tree',
            'date': None,
        }

    try:
        pieces = git_pieces_from_vcs(cfg.tag_prefix, root, verbose)
        return render(pieces, cfg.style)
    except NotThisMethod:
        pass

    try:
        if cfg.parentdir_prefix:
            return versions_from_parentdir(cfg.parentdir_prefix, root, verbose)
    except NotThisMethod:
        pass

    return {
        'version': '0+unknown', 'full-revisionid': None,
        'dirty': None,
        'error': 'unable to compute version', 'date': None,
    }



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import logging
import os
import sys

import click
import git
from colorama import init
from giturlparse import parse

# use Colorama to make Termcolor work on Windows too
init()


@click.command()
@click.option('-u', '--user', required=False, envvar='JIRA_USER', help='JIRA user')  # noqa: ignore=E501
@click.option('-p', '--password', required=False, prompt=True, hide_input=True, confirmation_prompt=True, envvar='JIRA_PASSWORD', help='JIRA password')  # noqa: ignore=E501
@click.option('-v', '--verbose', is_flag=True, default=False, help='Switch between INFO and DEBUG logging modes')  # noqa: ignore=E501
def cli(user=None, password=None, verbose=False):
    """Simple program that check a commit message. Try ./get_repo.py -v """

    logger.info('Collecting repo')

    if verbose:
        click.echo(user)
        # click.echo(password)
        click.echo(verbose)

    match_repo(verbose)


def _get_sha(git_repo, verbose=False):
    """
    Gets the org sha.

    :param git.Remote remote:
    :return: The sha
    :rtype: unicode, unicode
    """
    sha = git_repo.head.object.hexsha
    return sha


def _get_url(git_repo, verbose=False):
    """
    Gets the org url.

    :param git.Remote remote:
    :return: The url
    :rtype: unicode, unicode
    """
    url = git_repo.remotes.origin.url
    return url


def _get_org_and_name_from_remote(url, verbose=False):
    """
    Gets the org name and the repo name from remote.

    :param git.Remote remote:
    :return: The owner and the repo name in that order
    :rtype: unicode, unicode
    """
    if not url.endswith('.git'):
        url = '{}.git'.format(url)
    git_info = parse(url)
    if verbose:
        print('Repo owner: "{}"'.format(git_info.owner))
        print('Repo name: "{}"'.format(git_info.name))
    return git_info.owner, git_info.name


def match_repo(self, verbose=False) -> str:

    if verbose:
        logger.setLevel(logging.DEBUG)

    # Figure out which repo we're on
    git_repo = git.Repo(search_parent_directories=True)
    git_root = git_repo.git.rev_parse('--show-toplevel')

    # active_branch = git_repo .active_branch
    # same as name = git_repo .head.ref
    # name = git_repo .head.object.repo.name
    # name = git_repo .head.ref
    url = _get_url(git_repo)
    print(_get_org_and_name_from_remote(url))
    name = os.path.basename(git_root)  # git_repo.working_tree_dir

    print(name)

    # branch = check_output([
    #     'git', 'rev-parse', '--show-toplevel',
    # ]).strip().decode('utf-8')

    return name


logger = logging.getLogger('hooks.get_repo')
logger.setLevel(logging.INFO)
stdoutlog = logging.StreamHandler(sys.stdout)
logger.addHandler(stdoutlog)

if __name__ == '__main__':
    cli(None)



# -*- coding: utf-8 -*-
import os  # nosec
import subprocess  # nosec
import unittest

# echo "TEST" > ../.git/COMMIT_EDITMSG
# ./get_msg.py '../.git/COMMIT_EDITMSG' 'message'

# First install me : /opt/ansible/env38/bin/python3 setup.py install


class TestPackage(unittest.TestCase):
    def setUp(self):
        self.local_test_dir = os.path.dirname(os.path.realpath(__file__))

    def run_get_msg(self, cwd, bin, message, env=None):
        command = "{} {}".format(bin, message)

        result, err = subprocess.Popen(
            [command],
            cwd=cwd,
            stdin=subprocess.PIPE,
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            shell=True,  # nosec
            env=env,
        ).communicate()

        self.assertFalse(err, "Expected no error but was " + str(err))

        return result

    def test_message(self):
        cwd = self.local_test_dir
        binary = "../bin/get_msg"
        message = "data"

        result = self.run_get_msg(cwd=cwd, bin=binary, message=message)
        self.assertIn(
            "Use shell only when shell functionality is required",
            str(result),
        )


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright (c) 2018-2019 Alban Andrieu <alban.andrieu@free.fr>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
import errno
import sys


def main():
    print('Use shell only when shell functionality is required')


if __name__ == '__main__':
    try:
        sys.exit(main())
    except IOError as exc:
        if exc.errno != errno.EPIPE:
            raise
    except RuntimeError as e:
        raise SystemExit(str(e))



# -*- coding: utf-8 -*-
import re
import sys

import pytest

from hooks.get_jira import get_auth as script1  # The code to test
from hooks.get_jira import get_jira as script2  # The code to test

# http://blog.habnab.it/blog/2013/07/21/python-packages-and-you/
# from hooks import get_msg # NOK

# sys.path.append("../hooks")
sys.path.append("./hooks")


# python -m get_jira.get_jira feature/BMT-13403 -v
# python -m get_jira.get_auth -u aandrieu -p XXXX -v
# ./get_msg.py '../.git/COMMIT_EDITMSG'


def test_always_passes():
    assert True


# def test_always_fails():
#    assert False


def test_get_user():
    assert script1.get_user() == "aandrieu"


def test_get_user_nok():
    assert script1.get_user() != "toto"


def test_get_jira_url():
    my_url = script2.get_jira_url()
    print(my_url)
    # url_regex = re.compile(r"(?i)\b((?:https?://|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}/)(?:[^\s()<>]+|\(([^\s()<>]+|(\([^\s()<>]+\)))*\))+(?:\(([^\s()<>]+|(\([^\s()<>]+\)))*\)|[^\s`!()\[\]{};:'\".,<>?«»“”‘’]))", re.IGNORECASE) # noqa: E501
    url_regex = re.compile(r"^\w+")
    r1 = re.findall(url_regex, "https://localhost/jira")
    print(r1)
    z = url_regex.match(my_url)
    if z:
        print(z.groups)
    assert url_regex.match(my_url)
    # Matches.from_pattern(url_regex) == 'https://localhost/jira'
    # assert script2.get_jira_url() == "https://localhost/jira"


def myfunc():
    raise ValueError("https://localhost/jira")


def test_match():
    with pytest.raises(ValueError) as excinfo:
        myfunc()
    excinfo.match(r".*localhost.*")


def test_get_certificat_path():
    assert script2.get_certificat_path() == "/etc/ssl/certs/ca-certificates.crt"


# @pytest.mark.timeout(10)
# def test_get_msg():
#    assert script2.get_msg("test", "feature/BMT-13403") == "toto"



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import logging
import os
import re
import sys
import traceback
from typing import (  # for annotation purposes only
    #    Any,
    #    Dict,
    #    List,
    Tuple,
    #    Iterator,
    #    Pattern,
)

import certifi
import click
import urllib3
from colorama import init
from jira import JIRA
from jira.exceptions import JIRAError
from termcolor import colored

# from get_jira.get_auth import match_auth

http = urllib3.PoolManager(
    cert_reqs="CERT_REQUIRED",
    ca_certs=certifi.where(),
)

# use Colorama to make Termcolor work on Windows too
init()


@click.command()
@click.argument("current_message", type=str)
@click.argument("branch", type=str)
@click.option(
    "-u", "--user", required=False, envvar="JIRA_USER", help="JIRA user"
)  # noqa: ignore=E501
@click.option(
    "-p",
    "--password",
    required=False,
    prompt=False,
    hide_input=True,
    confirmation_prompt=True,
    envvar="JIRA_PASSWORD",
    help="JIRA password",
)  # noqa: ignore=E501
@click.option(
    "-v",
    "--verbose",
    is_flag=True,
    default=False,
    help="Switch between INFO and DEBUG logging modes",
)  # noqa: ignore=E501
@click.option(
    "-f", "--fail", is_flag=True, default=False, help="Fail if no issue JIRA found"
)  # noqa: ignore=E501
def cli(
    current_message: str,
    branch: str,
    fail=True,
    user=None,
    password=None,
    verbose=False,
) -> str:
    """Simple program that match jira. From hooks directory : Try
    python -m get_jira.get_jira BMT-13403 feature/TEST-13403 --verbose
    python -m get_jira.get_jira TEST feature/TEST-13403 --verbose
    python -m get_jira.get_jira 'Test message' feature/TEST-99999 --verbose
    """

    logger.info("Collecting JIRA")

    if verbose:
        click.echo(branch)
        click.echo(user)
        # click.echo(password)
        click.echo(fail)
        click.echo(verbose)

    basic_auth = match_auth(user, password)  # noqa: F821

    msg = get_msg(
        current_message=current_message,
        branch=branch,
        basic_auth=basic_auth,
        verbose=verbose,
        fail=fail,
    )

    print(colored("Message: {}".format(msg[0]), "magenta"))

    return msg


def get_msg(
    current_message: str,
    branch: str,
    basic_auth: Tuple[str, str] = ("", ""),
    verbose=True,
    fail=True,
) -> Tuple[str, str]:

    issue = match_issue(
        branch=branch,
        verbose=verbose,
    )

    required_message = ""

    # Test that message has not already been populated
    if issue not in current_message:
        required_message = match_jira(
            issue=issue,
            basic_auth=basic_auth,
            verbose=verbose,
        )

        # Appending current message
        required_message = "{} : {}".format(required_message, current_message)
    else:
        if verbose:
            print(
                colored(
                    "Issue number already detected in message: {}".format(
                        required_message
                    ),
                    "yellow",
                )
            )

    return required_message, issue


def match_issue(branch: str, verbose=False, fail=True) -> str:

    issue = "UNKNOWN"

    try:

        # Matches any unique issue code
        pattern = re.compile(
            r"(^feature|^feat|^bugfix|^fix|^docs|^style|^refactor|^perf|^test|^chore)\/([A-Z]{3,5}-[0-9]+)",  # noqa: E501
        )
        issue = re.search(pattern, branch).group(2)  # Extract issue code
        if verbose:
            print(colored("Issue number detected : {}.".format(issue), "green"))

    except Exception as e:  # noqa: ignore=E722
        if verbose:
            traceback.print_exc()
        print(
            colored(
                "Please set a valid JIRA",
                "red",
            ),
        )
        if fail:
            sys.exit(2)

    return issue


def get_jira_url() -> str:

    try:

        url = os.environ.get("JIRA_URL")

        if not url:
            server = "localhost/jira"
            url = "https://%s" % server

    except KeyError:
        print(
            colored(
                "Please set the environment variable JIRA_URL",
                "red",
            ),
        )
        sys.exit(3)

    return url


def get_certificat_path() -> str:

    try:

        certificat_path = os.environ.get("JIRA_CERT_PATH")

        if not certificat_path:
            certificat_path = "/etc/ssl/certs/ca-certificates.crt"

    except KeyError:
        print(
            colored(
                "Please set the environment variable JIRA_CERT_PATH",
                "red",
            ),
        )
        sys.exit(3)

    return certificat_path


def match_jira(
    issue: str, basic_auth: Tuple[str, str] = ("", ""), verbose=False
) -> str:

    # WORKAROUND below in case certificate is not install on workstation
    urllib3.disable_warnings()

    required_message = ""

    try:

        # print(colored('URL : {}.'.format(get_jira_url()), 'red'))

        options = {
            "server": get_jira_url(),
            "verify": False,
            # 'verify': True,
            # 'client_cert': get_certificat_path(),
        }

        jira = JIRA(options, basic_auth=basic_auth)

        issue_to_check = jira.issue(issue)
        status = "{}".format(issue_to_check.fields.status).strip().lower()

        issuetype = "{}".format(issue_to_check.fields.issuetype.name).strip().lower()

        # versions = jira.project_versions('TEST')
        # print(
        #     colored(
        #         'Versions : {}'.format(
        #             versions,
        #         ), 'magenta',
        #     ),
        # )
        # [v.name for v in reversed(versions)]

        if verbose:
            print(
                colored(
                    "Project key : {}".format(
                        issue_to_check.fields.project.key,
                    ),
                    "magenta",
                ),
            )
            print(
                colored(
                    "Issue Type : {}".format(
                        issuetype,
                    ),
                    "magenta",
                ),
            )  # 'Story'
            print(
                colored(
                    "Status : {}".format(
                        status,
                    ),
                    "magenta",
                ),
            )  # 'Story'
            print(
                colored(
                    "Reporter : {}".format(
                        issue_to_check.fields.reporter.displayName,
                    ),
                    "magenta",
                ),
            )

        statustocheck = ["closed", "done"]

        if any(sta in status for sta in statustocheck):
            print(
                colored(
                    "Status : {}".format(
                        status,
                    ),
                    "red",
                ),
            )
            sys.exit(3)

        required_message = "{} : {}".format(
            issue,
            issue_to_check.fields.issuetype.name,
        )
    except JIRAError as e:
        if verbose:
            traceback.print_exc()
        if e.status_code == 404:
            print(
                colored(
                    "{}".format(
                        e.text,
                    ),
                    "red",
                ),
            )
        if e.status_code == 401:
            print(
                colored(
                    "Login to JIRA failed. Check your username and password {}".format(
                        options,
                    ),
                    "red",
                ),
            )
    except Exception as e:  # noqa: ignore=E722
        if verbose:
            traceback.print_exc()
        print(
            colored(
                "Oops!  JIRA is failing. Switch to manual... {}".format(
                    issue,
                ),
                "red",
            ),
        )
        if jira:
            sys.exit(2)

    return required_message


logger = logging.getLogger("hooks.get_jira.get_jira")

if __name__ == "__main__":
    cli(None)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import getpass
import logging
import os
import sys
from typing import (  # for annotation purposes only
    #    Any,
    #    Dict,
    #    List,
    Tuple,
    #    Iterator,
    #    Pattern,
)

import click
from colorama import init
from termcolor import colored

# use Colorama to make Termcolor work on Windows too
init()


@click.command()
@click.option(
    "-u", "--user", required=False, envvar="JIRA_USER", help="JIRA user"
)  # noqa: ignore=E501
@click.option(
    "-p",
    "--password",
    required=False,
    prompt=True,
    hide_input=True,
    confirmation_prompt=True,
    envvar="JIRA_PASSWORD",
    help="JIRA password",
)  # noqa: ignore=E501
@click.option(
    "-v",
    "--verbose",
    is_flag=True,
    default=False,
    help="Switch between INFO and DEBUG logging modes",
)  # noqa: ignore=E501
def cli(user=None, password=None, verbose=False) -> Tuple[str, str]:
    """Simple program that match jira. From hooks directory : Try python -m get_jira.get_auth -u aandrieu -p XXXX --verbose"""  # noqa:E501

    logger.info("Collecting authentifcation")

    return match_auth(user, password, verbose)


def get_user(user=None, verbose=False) -> str:

    try:

        if not user:
            if verbose:
                print(
                    colored(
                        "User is empty, using JIRA_USER environement variable.",
                        "yellow",
                    ),
                )
            user = os.environ.get("JIRA_USER")
            if not user:
                user = os.environ.get("GIT_USERNAME")

        if not user:
            print(colored("User cannot be empty : {}.".format(user), "red"))
            sys.exit(3)

    except KeyError:
        print(
            colored(
                "Please set the environment variable JIRA_USER or GIT_USERNAME",
                "red",
            ),
        )
        sys.exit(3)

    # print(colored('User : {}.'.format(user), 'red'))

    return user


def get_password(password=None, verbose=False) -> str:

    try:

        if not password:
            if verbose:
                print(
                    colored(
                        "Password is empty, using JIRA_PASSWORD environement variable",
                        "yellow",
                    ),
                )
            password = os.environ.get("JIRA_PASSWORD")
            if not password:
                password = os.environ.get("GIT_ASSWORD")
            if not password:
                password = getpass.getpass()

            # TODO password should be crypted

        if not password:
            print(colored("Password cannot be empty : {}.".format(password), "red"))
            sys.exit(3)

    except KeyError:
        print(
            colored(
                "Please set the environment variable JIRA_PASSWORD or GIT_PASSWORD",
                "red",
            ),
        )
        sys.exit(3)

    # print(colored('Password : {}.'.format(password), 'red'))

    return password


def match_auth(user=None, password=None, verbose=False) -> Tuple[str, str]:

    if verbose:
        logger.setLevel(logging.DEBUG)
        click.echo(user)
        # click.echo(password)
        click.echo(verbose)

    user = get_user(user=user, verbose=verbose)

    password = get_password(password=password, verbose=verbose)

    basic_auth = (user, password)

    if not basic_auth:
        print(
            colored("Authentification cannot be empty : {}.".format(basic_auth), "red")
        )
        sys.exit(3)
    else:
        if verbose:
            print(basic_auth)
    return basic_auth


logger = logging.getLogger("hooks.get_jira.get_auth")
logger.setLevel(logging.INFO)
stdoutlog = logging.StreamHandler(sys.stdout)
logger.addHandler(stdoutlog)

if __name__ == "__main__":
    cli(None)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import logging
import os
import re
import sys
import traceback
from subprocess import check_output  # nosec

import click
import get_jira.get_auth
import get_jira.get_jira
from colorama import init
from termcolor import colored

# use Colorama to make Termcolor work on Windows too
init()

__all__ = ['match_msg']


@click.command()
@click.argument('commit_msg_filepath', type=click.Path(exists=False))
@click.argument('commit_type', type=str, default='')  # message for prepare-commit-msg
@click.option('-j', '--jira', is_flag=True, default=True, help='Jira check')  # noqa: ignore=E501
@click.option('-u', '--user', required=False, envvar='JIRA_USER', help='JIRA user')  # noqa: ignore=E501
@click.option('-p', '--password', required=False, prompt=True, hide_input=True, confirmation_prompt=True, envvar='JIRA_PASSWORD', help='JIRA password')  # noqa: ignore=E501
@click.option('-v', '--verbose', is_flag=True, default=False, help='Switch between INFO and DEBUG logging modes')  # noqa: ignore=E501
def cli(commit_msg_filepath, commit_type: str = '', jira=True, user=None, password=None, verbose=False):
    """
    Configures git hook commit message using CLI.

    :param str commit_msg_filepath: **required** *"./.git/COMMIT_EDITMSG"*, -
                    path of the file where the message is stored by git. If not provided, defaults to hostname

    :param str commit_msg_filepath: **default** *""*, -
                    Type of the message given by git. If not provided, defaults to empty

    :returns: Msg

    :example:

    .. code-block:: bash

             echo "TEST" > ../.git/COMMIT_EDITMSG
             ./get_msg.py '../.git/COMMIT_EDITMSG' 'message'

    """

    logger.info('Collecting branch')

    if verbose:
        click.echo(click.format_filename(commit_msg_filepath))
        click.echo(jira)
        click.echo(user)
        # click.echo(password)
        click.echo(verbose)

    return match_msg(
        commit_msg_filepath=commit_msg_filepath, commit_type=commit_type,
        jira=jira, user=user, password=password, verbose=verbose,
    )


def match_msg(commit_msg_filepath: str, commit_type: str = '', jira=True, user=None, password=None, verbose=False) -> str:
    """
    Configures git hook commit message.

    :param str commit_msg_filepath: **required** *"./.git/COMMIT_EDITMSG"*, -
                    path of the file where the message is stored by git. If not provided, defaults to hostname

    :param str commit_msg_filepath: **default** *""*, -
                    Type of the message given by git. If not provided, defaults to empty

    :returns: Msg
    """

    if verbose:
        logger.setLevel(logging.DEBUG)

    try:

        # Figure out which branch we're on
        branch = check_output([
            '/usr/bin/git', 'symbolic-ref', '--short',
            'HEAD',
        ]).strip().decode('utf-8')

        logger.debug(r"msg: On branch '{}'".format(branch))
        regex = re.compile('^feature|^bugfix')

        filename = os.path.expanduser(commit_msg_filepath)
        required_message = ''

        if os.path.exists(filename):
            with open(commit_msg_filepath, 'r+') as f:
                current_message = f.read()
                f.seek(0, 0)

            if not current_message:
                print(
                    colored(
                        'Current message is empty.', 'red',
                    ),
                )
            else:
                if verbose:
                    print(
                        colored(
                            'Message before is : {}'.format(
                                current_message,
                            ), 'yellow',
                        ),
                    )

            # Populate the commit message with the issue #, if there is one
            if re.match(regex, branch):
                if 'message' in commit_type:
                    print(
                        colored(
                            "Oh hey, it's an issue branch : {}.".format(
                                branch,
                            ), 'green',
                        ),
                    )

                if jira:
                    basic_auth = get_jira.get_auth.match_auth(
                        user=user, password=password, verbose=verbose,
                    )

                    msg = get_jira.get_jira.get_msg(
                        current_message=current_message, branch=branch, basic_auth=basic_auth, verbose=verbose,
                    )

                required_message = msg[0]

                if not required_message:
                    # Required message is empty
                    required_message = current_message

                if verbose:
                    print(
                        colored(
                            'Message after is : {}'.format(
                                required_message,
                            ), 'yellow',
                        ),
                    )
                with open(commit_msg_filepath, 'r+') as f:
                    f.seek(0, 0)
                    f.write('{}'.format(required_message))

        return required_message

    except:  # noqa: ignore=E722
        traceback.print_exc()
        sys.exit(2)


logger = logging.getLogger('hooks.get_msg')
logger.setLevel(logging.INFO)
stdoutlog = logging.StreamHandler(sys.stdout)
logger.addHandler(stdoutlog)

if __name__ == '__main__':
    cli(None)



# pylint: skip-file
import os

from setuptools import find_packages, setup

# import hooks
# from hooks._version import get_versions
# import versioneer

with open("requirements.txt") as f:
    requirements = f.read().splitlines()

# read the contents of your README file
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name="nabla-hooks",
    # version=hooks.__version__,
    # version=get_versions()['version'],
    # version="1.0.4",
    version=os.getenv("PACKAGE_VERSION"),
    # version=versioneer.get_version(),
    # cmdclass=versioneer.get_cmdclass(),
    packages=find_packages(),
    # scripts=["hooks/get_msg.py"],
    # Project uses reStructuredText, so ensure that the docutils get
    # installed or upgraded on the target machine
    setup_requires="setuptools-pipfile",
    # install_requires=["docutils>=0.3", "jira>=3.0.1", "termcolor>=1.1.0"],
    # install_requires=requirements,
    package_data={
        # If any package contains *.txt or *.rst files, include them:
        "": ["*.txt", "*.rst"],
        # And include any *.msg files found in the "hooks" package, too:
        "hooks": ["*.msg"],
    },
    # metadata to display on PyPI
    author="Alban Andrieu",
    author_email="alban.andrieu@free.fr",
    description="This is nabla_custom hooks package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords="nabla hooks",
    url="https://github.com/AlbanAndrieu/nabla-hooks",
    project_urls={
        "Bug Tracker": "https://github.com/AlbanAndrieu/nabla-hooks",
        "Documentation": "https://github.com/AlbanAndrieu/nabla-hooks",
        "Source Code": "https://github.com/AlbanAndrieu/nabla-hooks",
    },
    classifiers=[
        "Programming Language :: Python",
    ],
    entry_points={
        "console_scripts": [
            "nabla-hooks = hooks.get_msg:main",
        ],
    },
    # could also include long_description, download_url, etc.
)
